@@ -62,7 +62,7 @@ def codegen(schema, output, indent, skip=None):
     result = 'from collections import OrderedDict\n'
     result += 'from enum import Enum\n\n'
     result += 'import bare\n'
-    result += 'from bare.ast import TypeKind, BarePrimitive, StructType, OptionalType, NamedType, ArrayType, MapType, UnionType\n\n\n'
+    result += 'from bare.ast import TypeKind, BarePrimitive, StructType, OptionalType, NamedType, ArrayType, MapType, UnionType, UnionValue\n\n\n'
 
     schema = bare.parser.parse(schema)
 
